@@ -1,7 +1,6 @@
 library(variosig)
 library(gstat)
 library(sp)
-library(geoR)
 library(testthat)
 
 data(meuse)
@@ -18,13 +17,16 @@ expect_that(perm, is_a("list"))
 expect_that(envsig(perm, index = 2, method = "eb"), is_a("list"))
 expect_that(envplot(perm), is_a("character"))
 
-meuse <- as.geodata(obj = meuse, data.col = 4, covar.col = 1:3,
-                    covar.names = c("cadmium", "copper","lead"))
-meuse$data <- log(meuse$data)
-vario2 <- variog(meuse,max.dist=1500)
-perm2 <- envelope(vario2, meuse, nsim=9, cluster = TRUE, n.cluster = 10, max.dist=1500)
-expect_that(perm2, is_a("list"))
-expect_that(envsig(perm2, method = "eb"), is_a("list"))
-expect_that(envplot(perm2), is_a("character"))
+if (requireNamespace("geoR", quietly = TRUE)) {
+  library(geoR)
+  meuse <- as.geodata(obj = meuse, data.col = 4, covar.col = 1:3,
+                      covar.names = c("cadmium", "copper","lead"))
+  meuse$data <- log(meuse$data)
+  vario2 <- variog(meuse,max.dist=1500)
+  perm2 <- envelope(vario2, meuse, nsim=9, cluster = TRUE, n.cluster = 10, max.dist=1500)
+  expect_that(perm2, is_a("list"))
+  expect_that(envsig(perm2, method = "eb"), is_a("list"))
+  expect_that(envplot(perm2), is_a("character"))
+}
 
 
